@@ -18,6 +18,11 @@ public:
   size_t get_var_pos(size_t rt_index, size_t col_num);
   size_t get_num_vars(size_t rt_index);
   int get_max_end(size_t rt_index);
+  std::vector<std::vector<int> > get_var_starts_rectype();
+  std::vector<std::vector<int> > get_var_widths_rectype();
+  std::vector <size_t> get_num_vars_rectype();
+  std::vector<std::vector<size_t> > get_var_pos_rectype();
+  std::vector <int> get_max_ends_rectype();
 };
 
 #endif
